@@ -26,6 +26,8 @@
 #include <glib-object.h>
 #include <gdk/gdk.h>
 
+#include "vino-types.h"
+
 G_BEGIN_DECLS
 
 #define VINO_SERVER_DEFAULT_PORT  5900
@@ -40,7 +42,6 @@ G_BEGIN_DECLS
 #define VINO_IS_SERVER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), VINO_TYPE_SERVER))
 #define VINO_SERVER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), VINO_TYPE_SERVER, VinoServerClass))
 
-typedef struct _VinoServer        VinoServer;
 typedef struct _VinoServerClass   VinoServerClass;
 typedef struct _VinoServerPrivate VinoServerPrivate;
 typedef struct _VinoClient        VinoClient;
@@ -78,6 +79,10 @@ gboolean             vino_server_get_prompt_enabled       (VinoServer     *serve
 void                 vino_server_set_view_only            (VinoServer     *server,
 							   gboolean        view_only);
 gboolean             vino_server_get_view_only            (VinoServer     *server);
+void                 vino_server_set_display_status_icon  (VinoServer     *server,
+                                                           gboolean        display_status_icon);
+void                 vino_server_set_use_dbus_listener    (VinoServer     *server,
+                                                           gboolean        use_dbus_listener);
 gboolean             vino_server_get_use_alternative_port (VinoServer     *server);
 void                 vino_server_set_use_alternative_port (VinoServer     *server,
 							   gboolean        use_alternative_port);
@@ -107,9 +112,13 @@ void                 vino_server_set_disable_background   (VinoServer     *serve
                                                            gboolean        disable_background);
 gboolean             vino_server_get_disable_background   (VinoServer     *server);
 
-void                 vino_server_set_use_upnp              (VinoServer     *server,
-                                                            gboolean        use_upnp);
-gboolean             vino_server_get_use_upnp              (VinoServer     *server);
+void                 vino_server_set_use_upnp             (VinoServer     *server,
+                                                           gboolean        use_upnp);
+gboolean             vino_server_get_use_upnp             (VinoServer     *server);
+
+void                 vino_server_set_disable_xdamage      (VinoServer     *server,
+                                                           gboolean        disable_xdamage);
+gboolean             vino_server_get_disable_xdamage      (VinoServer     *server);
 
 #include "vino-status-icon.h"
 VinoStatusIcon      *vino_server_get_status_icon          (VinoServer      *server);
